@@ -31,6 +31,11 @@ def create_app(test_config=None):
     except OSError:
         pass
 
+    # a simple page that says hello
+    @app.route('/hello')
+    def hello():
+        return 'Hello, World!'
+
     # Read environment variables beginning with 'OSUCA', '_' gets dropped.
     app.config.from_prefixed_env('OSUCA')
     data_source = None
@@ -54,6 +59,9 @@ def create_app(test_config=None):
     from . import combination
     app.register_blueprint(combination.bp)
 
+    from . import summary 
+    app.register_blueprint(summary.bp)
+
     # Use app_context() in a with block, and everything that runs in the block
     # will have access to current_app.
     from . import api
