@@ -1,5 +1,4 @@
-from flask import Blueprint, render_template, request
-from werkzeug.exceptions import abort
+from flask import Blueprint, render_template, request, current_app
 
 from osuca.db import get_db
 
@@ -17,19 +16,18 @@ def combination(key, reverse):
         selection = db.course(selection_label)
         query_result = db.course_combination_aggregate(selection)
 
-    def course(cca):
-        return cca[0][0]
-
-    def count(cca):
-        return cca[1].count
-
-    def mean(cca):
-        return cca[1].mean
+    def course(cca): return cca[0][0]
+    def count(cca): return cca[1].count
+    def mean(cca): return cca[1].mean
     dispatcher = {'course': course, 'count': count, 'mean': mean}
+    row_limit = None
+    if 'ROW_LIMIT' in current_app.config:
+      row_limit = current_app.config['ROW_LIMIT']
 
     return render_template("combination.html",
                            selection_label=selection_label,
                            course=sorted(db.course()),
+                           row_limit=row_limit,
                            query_result=sorted(query_result,
                                                key=dispatcher[key],
                                                reverse=(reverse == 'True')))
